@@ -1,6 +1,6 @@
 package YAML::LoadBundle;
 # ABSTRACT: Load a directory of YAML files as a bundle
-$YAML::LoadBundle::VERSION = '0.002';
+$YAML::LoadBundle::VERSION = '0.003';
 use base qw(Exporter);
 use warnings;
 use strict;
@@ -189,7 +189,7 @@ sub _unravel_hash {
     }
 
     for my $elt (values %$data) {
-        $elt = _unravel($elt);
+        $elt = _unravel($elt) if ref($elt);
     }
 
     return $data;
@@ -457,7 +457,7 @@ YAML::LoadBundle - Load a directory of YAML files as a bundle
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
